==> custom_pages-v1.12.13.zip: custom_pages/messages/sl/base.php <==
<?php

return [
    'Advanced' => 'Napredno',
    'Back' => 'Nazaj',
    'Back to dashboard' => 'Nazaj na prvo stran',
    'Back to overview' => 'Nazaj na pregled',
    'Configuration' => 'Konfiguracija',
    'Content' => 'Vsebina',
    'Dashboard' => 'Prva stran',
    'Default' => 'Privzeto',
    'Delete' => 'Briši',
    'Edit' => 'Uredi',
    'General' => 'Splošno',
    'Settings' => 'Nastavitve',
    'Spaces' => 'Prostori',
    'Title' => 'Naslov',
    '<strong>Add</strong> {templateName} item' => '',
    '<strong>Custom</strong> Pages' => '',
    '<strong>Edit</strong> snippet' => '',
    'Add' => '',
    'Add a file icon before the title' => '',
    'Additional IFrame Attributes' => '',
    'Adds plain HTML content to your site.' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => '',
    'Allows you to add content in MarkDown syntax.' => '',
    'Alternate text' => '',
    'Always' => '',
    'Always make a backup of your view files outside of your production environment!' => '',
    'An empty allowed template selection will allow all container templates for this container.' => '',
    'Authors' => '',
    'Back to space' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Category' => '',
    'Container' => '',
    'Content filters' => '',
    'Create' => '',
    'Css Class' => '',
    'Custom' => '',
    'Custom Pages' => '',
    'Custom pages' => '',
    'Default Content' => '',
    'Deleted.' => '',
    'Edit Page' => '',
    'Empty' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'File' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Html' => '',
    'ID' => '',
    'Icon' => '',
    'Iframe' => '',
    'Import' => '',
    'Insert' => '',
    'Invalid request data!' => '',
    'Invalid template selection!' => '',
    'Invalid type selection' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Link' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'MarkDown' => '',
    'Menu settings' => '',
    'Navigation' => '',
    'Non-Logged-In Users' => '',
    'On this page you can configure general settings of your custom pages.' => '',
    'Overview' => '',
    'PHP' => '',
    'Page' => '',
    'Page Content' => '',
    'Pages' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => '',
    'Public' => '',
    'Reset' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Show additional file information (size)' => '',
    'Snippet' => '',
    'Snippets' => '',
    'Sort Order' => '',
    'Source' => '',
    'Space' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Stream' => '',
    'Stream options' => '',
    'Style' => '',
    'Style Class' => '',
    'Submit' => '',
    'Target Url' => '',
    'Template' => '',
    'Template Layout' => '',
    'Templates' => '',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => '',
    'This container does not allow any further items!' => '',
    'Top Navigation' => '',
    'Topics' => '',
    'Type' => '',
    'Upload image' => '',
    'Usage' => '',
    'User Account Menu (Settings)' => '',
    'Visibility' => '',
    'Will embed the result of a given url as an iframe element.' => '',
    'Will redirect requests to a given (relative or absolute) url.' => '',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => '',
    'Without adding to navigation (Direct link)' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/sl/base.php <==
<?php

return [
    'Advanced' => 'Napredno',
    'Back' => 'Nazaj',
    'Back to dashboard' => 'Nazaj na prvo stran',
    'Back to overview' => 'Nazaj na pregled',
    'Configuration' => 'Konfiguracija',
    'Content' => 'Vsebina',
    'Dashboard' => 'Prva stran',
    'Default' => 'Privzeto',
    'Delete' => 'Briši',
    'Edit' => 'Uredi',
    'General' => 'Splošno',
    'Settings' => 'Nastavitve',
    'Spaces' => 'Prostori',
    'Title' => 'Naslov',
    '<strong>Add</strong> {templateName} item' => '',
    '<strong>Custom</strong> Pages' => '',
    '<strong>Edit</strong> snippet' => '',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Add' => '',
    'Add a file icon before the title' => '',
    'Additional IFrame Attributes' => '',
    'Adds plain HTML content to your site.' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => '',
    'Allows you to add content in MarkDown syntax.' => '',
    'Alternate text' => '',
    'Always' => '',
    'Always make a backup of your view files outside of your production environment!' => '',
    'An empty allowed template selection will allow all container templates for this container.' => '',
    'Authors' => '',
    'Back to space' => '',
    'By creation date' => '',
    'By last update' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Category' => '',
    'Container' => '',
    'Content filters' => '',
    'Create' => '',
    'Css Class' => '',
    'Custom' => '',
    'Custom Pages' => '',
    'Custom pages' => '',
    'Default Content' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Edit Page' => '',
    'Empty' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'File' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Html' => '',
    'ID' => '',
    'Icon' => '',
    'Iframe' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Insert' => '',
    'Invalid request data!' => '',
    'Invalid template selection!' => '',
    'Invalid type selection' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Link' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'MarkDown' => '',
    'Menu settings' => '',
    'Navigation' => '',
    'Non-Logged-In Users' => '',
    'On this page you can configure general settings of your custom pages.' => '',
    'Overview' => '',
    'PHP' => '',
    'Page' => '',
    'Page Content' => '',
    'Pages' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => '',
    'Public' => '',
    'Reset' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Show additional file information (size)' => '',
    'Snippet' => '',
    'Snippets' => '',
    'Sort Order' => '',
    'Sorting' => '',
    'Source' => '',
    'Space' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Stream' => '',
    'Stream options' => '',
    'Style' => '',
    'Style Class' => '',
    'Submit' => '',
    'Target Url' => '',
    'Template' => '',
    'Template Layout' => '',
    'Templates' => '',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => '',
    'This container does not allow any further items!' => '',
    'Top Navigation' => '',
    'Topics' => '',
    'Type' => '',
    'Upload image' => '',
    'Usage' => '',
    'User Account Menu (Settings)' => '',
    'Visibility' => '',
    'Will embed the result of a given url as an iframe element.' => '',
    'Will redirect requests to a given (relative or absolute) url.' => '',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => '',
    'Without adding to navigation (Direct link)' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];
